<?php
/**
 * Category Block Four Customizer options
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */


// Add Category Block Four enable section
$wp_customize->add_section( 'daily_insight_pro_category_block_four_section', array(
	'title'             => esc_html__( 'Category Block Four','daily-insight-pro' ),
	'description'       => esc_html__( 'Category Block Four section options.', 'daily-insight-pro' ),
	'priority'			=> '10',
	'panel'             => 'daily_insight_pro_sections_panel'
) );

// Add Category Block Four enable setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[enable_category_block_four]', array(
	'default'           => $options['enable_category_block_four'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[enable_category_block_four]', array(
	'label'             => esc_html__( 'Check To Enable', 'daily-insight-pro' ),
	'section'           => 'daily_insight_pro_category_block_four_section',
	'type'              => 'checkbox',
) );

// Add Category Block Four content type setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_four_type]', array(
	'default'           => $options['category_block_four_type'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_select'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_four_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_four_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'daily_insight_pro_is_category_block_four_active',
	'choices'         	=> array(
		'demo'			=> esc_html__( 'Demo','daily-insight-pro'),
		'category'		=> esc_html__( 'Category', 'daily-insight-pro' ),	
	)
) );

// Add enable arrow controls setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[enable_slider_controls_category_block_four]', array(
	'default'           => $options['enable_slider_controls_category_block_four'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[enable_slider_controls_category_block_four]', array(
	'label'           => esc_html__( 'Enable Arrow Controls', 'daily-insight-pro' ),
	'section'         => 'daily_insight_pro_category_block_four_section',
	'type'            => 'checkbox',
	'active_callback' => 'daily_insight_pro_is_category_block_four_content_as_category',
) );

// Add enable slider dragable setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[enable_slider_dragable_category_block_four]', array(
	'default'           => $options['enable_slider_dragable_category_block_four'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[enable_slider_dragable_category_block_four]', array(
	'label'           => esc_html__( 'Slider Dragable', 'daily-insight-pro' ),
	'section'         => 'daily_insight_pro_category_block_four_section',
	'type'            => 'checkbox',
	'active_callback' => 'daily_insight_pro_is_category_block_four_content_as_category',
) );

// Add enable slider pause on hover setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[slider_pause_on_hover_category_block_four]', array(
	'default'           => $options['slider_pause_on_hover'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[slider_pause_on_hover_category_block_four]', array(
	'label'           => esc_html__( 'Pause On Hover', 'daily-insight-pro' ),
	'section'         => 'daily_insight_pro_category_block_four_section',
	'type'            => 'checkbox',
	'active_callback' => 'daily_insight_pro_is_category_block_four_content_as_category',
) );

// Add Category Block Four number of posts setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_four_no_of_posts]', array(
	'default'           => $options['category_block_four_no_of_posts'],
	'validate_callback' => 'daily_insight_pro_validate_no_of_category_block_four',
	'sanitize_callback' => 'daily_insight_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_four_no_of_posts]', array(
	'label'           	=> esc_html__( 'Number Of Category Block Four', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_four_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'daily_insight_pro_is_category_block_four_content_as_category',
	'input_attrs'		=> array(
		'min'			=> '5',
		'max'			=> '10',
		'step'			=> '1',
		'style'			=> 'width:50px',
		),
) );

// Add Category Block Four category drop-down setting and control
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_four_category_type]', array(
	'default'			=> $options['category_block_four_category_type'],			
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( new Daily_Insight_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_four_category_type]', array(
	'active_callback' 	=> 'daily_insight_pro_is_category_block_four_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_four_section',
	'type'            	=> 'dropdown-taxonomies',
 ) ) );

