<?php
/**
 * Counter Widget
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

if ( ! class_exists( 'Daily_Insight_Pro_Counter_Widget' ) ) :
/**
 * Counter Class
 *
 * @since 1.0
 *
 * @see WP_Widget
 */
class Daily_Insight_Pro_Counter_Widget extends WP_Widget {

	/**
	 * Sets up a new Counter widget instance.
	 *
	 * @since 1.0
	 * @access public
	 */
	public function __construct() {
		$widget_ops = array(
			'classname'                   => 'widget_features',
			'description'                 => esc_html__( 'Shows Your site&#8217;s most recent comments with extra features.','daily-insight-pro' ),
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'tp-widget-features', esc_html__( 'TP: Counter Widget', 'daily-insight-pro' ), $widget_ops );
		$this->alt_option_name = 'widget_features';
	}

	/**
	 * Outputs the content for the Counter widget instance.
	 *
	 * @since 1.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the Counter widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

			$title             = ( !empty( $instance['title'] ) ) ? $instance['title'] : '';

			/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
			$title             = apply_filters( 'widget_title', $title, $instance, $this->id_base );

			$no_of_features = !empty( $instance['no_of_features'] ) ? absint( $instance['no_of_features'] ) : 4;

		echo $args['before_widget'];
		if ( ! empty( $title ) ) {
			echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
		}
		
		echo '<div class="widget-wrap">
				<ul>';
		for( $i=1; $i <= $no_of_features; $i++ ){
			$feature_title        = !empty( $instance['feature_title_'. $i ] ) ? $instance['feature_title_'. $i ] : '';
			$feature_fa_icon      = !empty( $instance['feature_fa_icon_'. $i ] ) ? $instance['feature_fa_icon_'. $i ] : '';
			$feature_number_value = !empty( $instance['feature_number_value_'. $i ] ) ? $instance['feature_number_value_'. $i ] : '';

			if( !empty( $feature_title ) || !empty( $feature_fa_icon ) || !empty( $feature_number_value ) ){
		?>
            <li>
              <div class="features">
                <i class="<?php echo esc_attr( $feature_fa_icon );?>"></i>
                <h2><?php echo esc_html( $feature_number_value );?></h2>
                <span><?php echo esc_html( $feature_title );?></span>
              </div><!-- .features -->
            </li>
        <?php
    		}
    	}
        echo '</ul>
        </div><!-- .widget-wrap -->';
		echo $args['after_widget'];
	}

	/**
	 * Handles updating settings for the Counter widget instance.
	 *
	 * @since 1.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance                   = $old_instance;
		$instance['title']          = sanitize_text_field( $new_instance['title'] );
		$instance['no_of_features'] = absint( $new_instance['no_of_features'] );

		for( $i= 1; $i<=$instance['no_of_features']; $i++ ){
			$instance['feature_title_'. $i ]        = sanitize_text_field( $new_instance['feature_title_'. $i ] );
			$instance['feature_fa_icon_'. $i ]      = sanitize_text_field( $new_instance['feature_fa_icon_'. $i ] );
			$instance['feature_number_value_'. $i ] = absint( $new_instance['feature_number_value_'. $i ] );
		}
		return $instance;
	}

	/**
	 * Outputs the settings form for the Counter widget.
	 *
	 * @since 1.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {

		$title     	= isset( $instance['title'] ) ? ( $instance['title'] ) : '';
		$no_of_features 	= isset( $instance['no_of_features'] ) ? absint( $instance['no_of_features'] ) : 4;
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'daily-insight-pro' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'no_of_features' ) ); ?>"><?php esc_html_e( 'Number of Features:', 'daily-insight-pro' ); ?></label>
			<input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'no_of_features' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'no_of_features' ) ); ?>" type="number" step="1" min="1" value="<?php echo absint( $no_of_features ); ?>"/>
		</p>

		<?php for( $i= 1; $i<=$no_of_features; $i++ ) {
			$feature_title = !empty( $instance['feature_title_'. $i] ) ? $instance['feature_title_'. $i] : '';
			$feature_fa_icon = !empty( $instance['feature_fa_icon_'. $i] ) ? $instance['feature_fa_icon_'. $i] : '';
			$feature_number_value = !empty( $instance['feature_number_value_'. $i] ) ? absint( $instance['feature_number_value_'. $i] ) : 0;
		?>
		<p>
			<hr style="color:black; align:center; size:5px;">
			<label for="<?php echo esc_attr( $this->get_field_id( 'feature_title_'. $i ) ); ?>"><?php esc_html_e( 'Feature Title :', 'daily-insight-pro' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'feature_title_'. $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'feature_title_'. $i ) ); ?>" type="text" value="<?php echo esc_attr( $feature_title ); ?>" placeholder="<?php esc_html_e( 'Enter feature title', 'daily-insight-pro'); ?>"/>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'feature_fa_icon_'. $i ) ); ?>"><?php esc_html_e( 'Feature Icon :', 'daily-insight-pro' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'feature_fa_icon_'. $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'feature_fa_icon_'. $i ) ); ?>" type="text" value="<?php echo esc_attr( $feature_fa_icon ); ?>" placeholder="fa fa-glass"/>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'feature_number_value_'. $i ) ); ?>"><?php esc_html_e( 'Feature Value :', 'daily-insight-pro' ); ?></label>
			<input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'feature_number_value_'. $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'feature_number_value_'. $i ) ); ?>" type="number" value="<?php echo absint( $feature_number_value ); ?>"/>
		</p>
		<?php }
	}
}
endif;
/*
 * Function to register counter widget
 *
 * Since 1.0
 */
function daily_insight_pro_register_conter_widget(){
	register_widget( 'Daily_Insight_Pro_Counter_Widget' );
}
add_action( 'widgets_init', 'daily_insight_pro_register_conter_widget' );